"""Group Center 功能模块
Group Center Feature Module

该模块提供了群组管理的功能扩展，包括：
This module provides feature extensions for group management, including:
- 用户通知 / User notifications
- 自定义消息 / Custom messages
"""

__all__ = [
    "nvi_notify",  # 通知模块 / Notify module
]

from . import nvi_notify  # 通知模块 / Notify module
