# """Group Center 示例模块
# Group Center Example Module
#
# 该模块提供了群组管理的示例功能，包括：
# This module provides example functionalities for group management, including:
# - RTSP 推流 / RTSP streaming
# - OpenCV 示例 / OpenCV examples
# """

__all__ = [
    "rtsp",  # RTSP 模块 / RTSP module
]

from . import rtsp  # RTSP 模块 / RTSP module
